==> haskell-persistent-2.14.5.2-23-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent
version:              2.14.5.2
visibility:           public
id:                   persistent-2.14.5.2-GPWHCW8fdRqGAAF6p19mHm
key:                  persistent-2.14.5.2-GPWHCW8fdRqGAAF6p19mHm
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  6f56003b30bfb6492cd538b3bfeac3a9
exposed:              True
exposed-modules:
    Database.Persist Database.Persist.Class
    Database.Persist.Class.PersistConfig
    Database.Persist.Class.PersistEntity
    Database.Persist.Class.PersistField
    Database.Persist.Class.PersistQuery
    Database.Persist.Class.PersistStore
    Database.Persist.Class.PersistUnique Database.Persist.Compatible
    Database.Persist.EntityDef Database.Persist.EntityDef.Internal
    Database.Persist.FieldDef Database.Persist.FieldDef.Internal
    Database.Persist.ImplicitIdDef
    Database.Persist.ImplicitIdDef.Internal Database.Persist.Names
    Database.Persist.PersistValue Database.Persist.Quasi
    Database.Persist.Quasi.Internal Database.Persist.Sql
    Database.Persist.Sql.Migration Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.SqlBackend
    Database.Persist.SqlBackend.Internal
    Database.Persist.SqlBackend.Internal.InsertSqlResult
    Database.Persist.SqlBackend.Internal.IsolationLevel
    Database.Persist.SqlBackend.Internal.MkSqlBackend
    Database.Persist.SqlBackend.Internal.SqlPoolHooks
    Database.Persist.SqlBackend.Internal.Statement
    Database.Persist.SqlBackend.Internal.StatementCache
    Database.Persist.SqlBackend.SqlPoolHooks
    Database.Persist.SqlBackend.StatementCache Database.Persist.TH
    Database.Persist.Types

hidden-modules:
    Database.Persist.Types.Base Database.Persist.Sql.Internal
    Database.Persist.Sql.Types Database.Persist.Sql.Raw
    Database.Persist.Sql.Run Database.Persist.Sql.Class
    Database.Persist.Sql.Orphan.PersistQuery
    Database.Persist.Sql.Orphan.PersistStore
    Database.Persist.Sql.Orphan.PersistUnique
    Database.Persist.Compatible.Types Database.Persist.Compatible.TH

import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-2.14.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-2.14.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-2.14.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent
hs-libraries:         HSpersistent-2.14.5.2-GPWHCW8fdRqGAAF6p19mHm
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg
    attoparsec-0.14.4-DYbgeBOmAIRHL8NoYiOyFW
    attoparsec-aeson-2.1.0.0-DdR79qVZCk28xrg7JfXfeG base-4.17.2.1
    base64-bytestring-1.2.1.0-Fa0BuK0N9mu9JPJP7gaxRT
    blaze-html-0.9.2.0-BsVDj7UmD9SGJonPOQFUuj bytestring-0.11.5.3
    conduit-1.3.6.1-E440ekNNgW6K3EfLZREfa1 containers-0.6.7
    deepseq-1.4.8.0 fast-logger-3.2.4-GrQ8nFhR5mpA8EuxDsGHQ2
    http-api-data-0.6.1-FahDGTMw50P4NKEAb3IwkU
    lift-type-0.1.2.0-3WYdJk8SJsICxPJiTvj80U
    monad-logger-0.3.42-JkMW6I4lRDO9lIgdCqxRwW mtl-2.2.2
    path-pieces-0.2.1-3XB1w9Pq9G55ySSfgWLsAv
    resource-pool-0.2.3.2-5oQsv6yyKmlCMdNDJD8QG7
    resourcet-1.2.6-KOK8YcGoRtO4DzojWOYtyP
    scientific-0.3.8.0-L88GQ4rEhQfGc3NVSCAVTu
    silently-1.2.5.4-9u7UVppGqLDJYp1Db2hbZU template-haskell-2.19.0.0
    text-2.0.2 th-lift-instances-0.1.20-4HlXS6eUQvv3LpmmJLLB0s
    time-1.12.2 transformers-0.5.6.2
    unliftio-0.2.25.1-83PwQVOhURl3H5nxoMcX3o
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk
    vault-0.3.1.5-Euat3gnPaqr1JFGOFA9eru
    vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57

haddock-interfaces:   /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html:         /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-2.14.5.2-44-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent
version:              2.14.5.2
visibility:           public
id:                   persistent-2.14.5.2-4XQ911owVSTIyWoNtMmSaI
key:                  persistent-2.14.5.2-4XQ911owVSTIyWoNtMmSaI
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  30f5a70fda3691e0e7f9a5f7e0ff1658
exposed:              True
exposed-modules:
    Database.Persist Database.Persist.Class
    Database.Persist.Class.PersistConfig
    Database.Persist.Class.PersistEntity
    Database.Persist.Class.PersistField
    Database.Persist.Class.PersistQuery
    Database.Persist.Class.PersistStore
    Database.Persist.Class.PersistUnique Database.Persist.Compatible
    Database.Persist.EntityDef Database.Persist.EntityDef.Internal
    Database.Persist.FieldDef Database.Persist.FieldDef.Internal
    Database.Persist.ImplicitIdDef
    Database.Persist.ImplicitIdDef.Internal Database.Persist.Names
    Database.Persist.PersistValue Database.Persist.Quasi
    Database.Persist.Quasi.Internal Database.Persist.Sql
    Database.Persist.Sql.Migration Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.SqlBackend
    Database.Persist.SqlBackend.Internal
    Database.Persist.SqlBackend.Internal.InsertSqlResult
    Database.Persist.SqlBackend.Internal.IsolationLevel
    Database.Persist.SqlBackend.Internal.MkSqlBackend
    Database.Persist.SqlBackend.Internal.SqlPoolHooks
    Database.Persist.SqlBackend.Internal.Statement
    Database.Persist.SqlBackend.Internal.StatementCache
    Database.Persist.SqlBackend.SqlPoolHooks
    Database.Persist.SqlBackend.StatementCache Database.Persist.TH
    Database.Persist.Types

hidden-modules:
    Database.Persist.Types.Base Database.Persist.Sql.Internal
    Database.Persist.Sql.Types Database.Persist.Sql.Raw
    Database.Persist.Sql.Run Database.Persist.Sql.Class
    Database.Persist.Sql.Orphan.PersistQuery
    Database.Persist.Sql.Orphan.PersistStore
    Database.Persist.Sql.Orphan.PersistUnique
    Database.Persist.Compatible.Types Database.Persist.Compatible.TH

import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-2.14.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-2.14.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-2.14.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent
hs-libraries:         HSpersistent-2.14.5.2-4XQ911owVSTIyWoNtMmSaI
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk
    attoparsec-0.14.4-D6xkbFZLQBXDD0qvU7o55y
    attoparsec-aeson-2.1.0.0-BaIGvxJAWCx43bSANq38ez base-4.17.2.1
    base64-bytestring-1.2.1.0-G8BjkxE58WI1uqeVjCB0n4
    blaze-html-0.9.2.0-3cSCYM9QSR99BQnVHXrYzE bytestring-0.11.5.3
    conduit-1.3.6.1-YyCKRGvJ9RFx9ccf8Rnd3 containers-0.6.7
    deepseq-1.4.8.0 fast-logger-3.2.4-CmUTOIzlIrP2oPyQXhvG8f
    http-api-data-0.6.1-Ct3YGnpgXQS6uC3vp2y6CM
    lift-type-0.1.2.0-7FHxjY0KFsR85dr3CoWVon
    monad-logger-0.3.42-LuCAjjjmxzACtBdHBvTKdG mtl-2.2.2
    path-pieces-0.2.1-3XB1w9Pq9G55ySSfgWLsAv
    resource-pool-0.2.3.2-IwokjjpbTKCEUx26uJ9tBR
    resourcet-1.2.6-7JBHLKMrq1iCQRZHHoRMKl
    scientific-0.3.8.0-6QoqQGQc0yZ1FsULZsdy9C
    silently-1.2.5.4-9u7UVppGqLDJYp1Db2hbZU template-haskell-2.19.0.0
    text-2.0.2 th-lift-instances-0.1.20-HSRjlGXAGtLJZoUMZdls5z
    time-1.12.2 transformers-0.5.6.2
    unliftio-0.2.25.1-jUDvU4O8PS8SoQvWmG5yt
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM
    vault-0.3.1.5-BHykSY1WJa8JS453tvnLdt
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS

haddock-interfaces:   /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html:         /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
